@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: array.h,v 1.1 2005/07/26 11:41:50 evertonm Exp $ */
+/* $Id: array.h,v 1.2 2005/09/18 18:28:51 evertonm Exp $ */
 
 #ifndef NEPIM_ARRAY_H
 #define NEPIM_ARRAY_H
@@ -36,6 +36,10 @@ void nepim_array_delete(nepim_array_t *array);
 
 void *nepim_array_get(const nepim_array_t *array, int index);
 void *nepim_array_search(const nepim_array_t *array, int index);
+void *nepim_array_find(const nepim_array_t *array,
+		       int (*detector)(const void *context,
+				       const void *element),
+		       const void *context);
 int nepim_array_find_free(nepim_array_t *array);
 
 void nepim_array_add(nepim_array_t *array, int index, void *value);
