@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: client.c,v 1.35 2005/09/18 19:37:00 evertonm Exp $ */
+/* $Id: client.c,v 1.37 2005/09/22 10:24:56 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -78,15 +78,22 @@ static void *on_tcp_read(oop_source *src, int sd,
 
   assert(sizeof(buf) == nepim_global.tcp_read_size);
 
+  errno = 0;
+
   rd = read(sd, buf, nepim_global.tcp_read_size);
-  if (rd < 0) {
-    switch (errno) {
-    case EINTR:
-      fprintf(stderr, "read: EINTR on TCP socket %d\n", sd);
-      return OOP_CONTINUE;
-    case EAGAIN:
-      fprintf(stderr, "read: EAGAIN on TCP socket %d\n", sd);
-      return OOP_CONTINUE;
+  if (rd <= 0) {
+    if (rd) {
+      switch (errno) {
+      case EINTR:
+	fprintf(stderr, "read: EINTR on TCP socket %d\n", sd);
+	return OOP_CONTINUE;
+      case EAGAIN:
+	fprintf(stderr, "read: EAGAIN on TCP socket %d\n", sd);
+	return OOP_CONTINUE;
+      default:
+	fprintf(stderr, "read: errno=%d: %s\n",
+		errno, strerror(errno));
+      }
     }
 
     fprintf(stderr, "read: connection lost on TCP socket %d\n", sd);
@@ -360,6 +367,7 @@ static int greet(int sd)
   nepim_greet_t opt;
   int pr;
   int wr;
+  char *tmp = "";
 
   opt.must_send             = nepim_global.duplex_mode ||
     !nepim_global.simplex_client_send;
@@ -371,6 +379,15 @@ static int greet(int sd)
   opt.udp_keepalive_send    = -1;
   opt.udp_keepalive_require = -1;
 
+  if (nepim_global.password) {
+    opt.password_buf        = nepim_global.password;
+    opt.password_buf_size   = strlen(nepim_global.password) + 1;
+  }
+  else {
+    opt.password_buf        = tmp;
+    opt.password_buf_size   = strlen(tmp) + 1;
+  }
+
   pr = nepim_write_greetings(&opt, buf, sizeof(buf));
   if (pr < 0)
     return -1;
