@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: common.c,v 1.40 2005/09/29 00:15:55 evertonm Exp $ */
+/* $Id: common.c,v 1.42 2005/10/13 19:57:39 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,7 +40,7 @@ const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
 const char *nepim_version()
 {
-  return "0.14";
+  return "0.15";
 }
 
 static void nepim_dump_stat(FILE *out, const char *label,
@@ -97,9 +97,12 @@ void nepim_slot_stat(FILE *out, const char *label, int sd,
 		  reads, writes);
 
   if (nepim_global.udp_exp_stats) {
-    float loss_ratio = 100 * pkt_lost; loss_ratio /= reads;
-    float dup_ratio = 100 * pkt_dup;   dup_ratio /= reads;
-
+    float loss_ratio = 100 * pkt_lost;
+    float dup_ratio = 100 * pkt_dup;
+    
+    loss_ratio /= reads;
+    dup_ratio /= reads;
+    
     fprintf(out,
 	    " lost=%d/%.2f%% dup=%d/%.2f%%",
 	    pkt_lost, loss_ratio, pkt_dup, dup_ratio);
