@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.29 2005/09/29 12:48:38 evertonm Exp $
+  $Id: main.c,v 1.31 2005/10/13 19:02:20 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -78,45 +78,46 @@ static void usage(FILE *out, const char *prog_name)
 	  "usage: %s [options]\n"
 	  "\n"
 	  "common (client/server) options:\n"
-	  "  -h            help\n"
-	  "  -v            show program version\n"
-	  "  -p port       server port number (defaults to %s)\n"
-	  "  -m mode       path MTU discovery mode (defaults to %d)\n"
-	  "                modes: -1 = use system-wide settings\n"
-	  "                        0 = DONT (never do PMTU discovery, DF=0)\n"
-	  "                        1 = WANT (use per-route hints)\n"
-	  "                        2 = DO   (always do PMTU discovery, DF=1)\n"
-	  "  -t ttl        TTL for sending packets (defaults to system)\n"
-	  "  -w size       TCP write size (defaults to %d bytes)\n"
-	  "  -z size       TCP read size (defaults to %d bytes)\n"
-	  "  -W size       UDP write size (defaults to %d bytes)\n"
-	  "  -Z size       UDP read size (defaults to %d bytes)\n"
-	  "  -O size       maximum socket send buffer in bytes\n"
-	  "  -I size       maximum socket receive buffer in bytes\n"
-	  "  -k password   server authentication secret\n"
-	  "  -6            disable IPv6\n"
-	  "  -4            disable IPv4\n"
-	  "  -x [win]      experimental UDP reception statistics (win=%d)\n"
-	  "  -L loss       experimental UDP sending loss\n"
-	  "  -D dup        experimental UDP sending duplication\n"
+	  "  -h             help\n"
+	  "  -v             show program version\n"
+	  "  -p port        server port number (defaults to %s)\n"
+	  "  -m mode        path MTU discovery mode (defaults to %d)\n"
+	  "                 modes: -1 = use system-wide settings\n"
+	  "                         0 = DONT (never do PMTU discovery, DF=0)\n"
+	  "                         1 = WANT (use per-route hints)\n"
+	  "                         2 = DO   (always do PMTU discovery, DF=1)\n"
+	  "  -t ttl         TTL for sending packets (defaults to system)\n"
+	  "  -w size        TCP write size (defaults to %d bytes)\n"
+	  "  -z size        TCP read size (defaults to %d bytes)\n"
+	  "  -W size        UDP write size (defaults to %d bytes)\n"
+	  "  -Z size        UDP read size (defaults to %d bytes)\n"
+	  "  -O size        maximum socket send buffer in bytes\n"
+	  "  -I size        maximum socket receive buffer in bytes\n"
+	  "  -k password    server authentication secret\n"
+	  "  -6             disable IPv6\n"
+	  "  -4             disable IPv4\n"
+	  "  -x [win]       experimental UDP reception statistics (win=%d)\n"
+	  "  -L loss        experimental UDP sending loss\n"
+	  "  -D dup         experimental UDP sending duplication\n"
 	  "client-only options:\n"
-	  "  -u            UDP mode (defaults to TCP)\n"
-	  "  -s            client-send simplex mode (defaults to server-send)\n"
-	  "  -d            duplex traffic (defaults to simplex)\n"
-	  "  -M            enable multicast-compatible options\n"
-	  "  -c host-list  client mode (defaults to server mode)\n"
-	  "  -n pipes      number of parallel pipes (defaults to %d)\n"
-	  "  -r bit-rate   upper bit rate limit (defaults to %s bps)\n"
-	  "  -R pkt-rate   upper packet rate limit (defaults to %s pps)\n"
-	  "  -i interval   statistics report interval (defaults to %d seconds)\n"
-	  "  -a age        test duration (defaults to %d seconds)\n"
+	  "  -u             UDP mode (defaults to TCP)\n"
+	  "  -s             client-send simplex mode (defaults to server-send)\n"
+	  "  -d             duplex traffic (defaults to simplex)\n"
+	  "  -M             enable multicast-compatible options\n"
+	  "  -c host-list   client mode (defaults to server mode)\n"
+	  "  -n pipes       number of parallel pipes (defaults to %d)\n"
+	  "  -r bit-rate    upper bit rate limit (defaults to %s bps)\n"
+	  "  -R pkt-rate    upper packet rate limit (defaults to %s pps)\n"
+	  "  -i interval    statistics report interval (defaults to %d seconds)\n"
+	  "  -a age         test duration (defaults to %d seconds)\n"
 	  "server-only options:\n"
-	  "  -b addr-list  bind to specific addresses (defaults to any)\n"
-	  "  -j addr-list  join multicast groups (defaults to empty)\n"
-	  "                addr-list: addr_1[,port_1][/.../addr_n[,port_n]]\n"
-	  "                example:   10.0.0.1/192.168.0.1,5000/::1\n"
-	  "  -l backlog    TCP listen(2) backlog (defaults to %d)\n"
-	  "  -T mcast-ttl  TTL for multicast packets (defaults to system)\n"
+	  "  -f [lib-name]  enable TCP wrapper filtering\n"
+	  "  -b addr-list   bind to specific addresses (defaults to any)\n"
+	  "  -j addr-list   join multicast groups (defaults to empty)\n"
+	  "                 addr-list: addr_1[,port_1][/.../addr_n[,port_n]]\n"
+	  "                 example:   10.0.0.1/192.168.0.1,5000/::1\n"
+	  "  -l backlog     TCP listen(2) backlog (defaults to %d)\n"
+	  "  -T mcast-ttl   TTL for multicast packets (defaults to system)\n"
 	  ,
 	  nepim_global.prog_name, 
 	  nepim_global.portname,
@@ -181,6 +182,20 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-f")) {
+      int j = i + 1;
+
+      nepim_global.tcpwrap = "libwrap.so";
+      
+      if (j < argc)
+	if (*argv[j] != '-') {
+	  ++i;
+	  nepim_global.tcpwrap = argv[i];
+	}
+
+      continue;
+    }
+
     if (!strcmp(arg, "-L")) {
       ++i;
       if (i >= argc) {
