@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: server.c,v 1.42 2005/09/22 10:24:56 evertonm Exp $ */
+/* $Id: server.c,v 1.44 2005/10/13 19:02:20 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,6 +39,7 @@ Boston, MA 02111-1307, USA.
 #include "slot.h"
 #include "usock.h"
 #include "str.h"
+#include "tcpwrap.h"
 
 nepim_pipe_set_t  pipes;   /* tcp socket table */
 nepim_slot_set_t  slots;   /* udp pseudo-sockets */
@@ -580,6 +581,19 @@ static void *on_tcp_connect(oop_source *src, int sd,
 	  conn_sd, addr_buf, 
 	  nepim_sock_get_port((const struct sockaddr *) &sa));
 
+  if (nepim_global.tcpwrap) {
+    if (!nepim_hosts_ctl(nepim_global.tcpwrap,
+			 nepim_global.prog_name,
+			 addr_buf)) {
+      fprintf(stderr, 
+	      "%d: %s: %s: TCP wrapper denied access from client=[%s] to service=[%s]\n",
+	      conn_sd, __FILE__, __PRETTY_FUNCTION__,
+	      addr_buf, nepim_global.prog_name);
+      close(conn_sd);
+      return OOP_CONTINUE;
+    }
+  }
+
   result = nepim_socket_opt(conn_sd, nepim_global.pmtu_mode, 
 			    nepim_global.ttl);
   if (result) {
