@@ -19,16 +19,18 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: session.h,v 1.9 2005/08/17 02:24:29 evertonm Exp $ */
+/* $Id: session.h,v 1.11 2005/09/12 23:41:41 evertonm Exp $ */
 
 #ifndef NEPIM_SESSION_H
 #define NEPIM_SESSION_H
 
+#include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <sys/time.h>
 
 #include "greet.h"
+#include "usec.h"
 
 typedef enum { SESSION_PIPE, SESSION_SLOT } nepim_session_type;
 
@@ -53,9 +55,9 @@ struct nepim_session_t {
   int max_pkt_rate;
   int stat_interval;
   int test_duration;
-  suseconds_t write_delay; /* usec, used when max_bit_rate > 0 */
-  int duration_done;       /* boolean */
-  int udp_keepalive_send;  /* boolean, non-senders */
+  susec_t write_delay;       /* usec, used when max_bit_rate > 0 */
+  int duration_done;         /* boolean */
+  int udp_keepalive_send;    /* boolean, non-senders */
   int udp_keepalive_require; /* boolean, receivers */
 
   int rate_remaining;        /* bytes, used when max_bit_rate > 0 */
