@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: slot.c,v 1.25 2005/09/18 18:28:51 evertonm Exp $ */
+/* $Id: slot.c,v 1.27 2005/09/30 11:55:40 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -104,6 +104,8 @@ void nepim_slot_set_add(nepim_slot_set_t *set, int sd,
   slot->interval_pkt_dup  = 0;
   slot->total_pkt_lost    = 0;
   slot->total_pkt_dup     = 0;
+  slot->exp_loss_sampler  = 0;
+  slot->exp_dup_sampler   = 0;
   
   nepim_session_init(&slot->session, opt, 
 		     remote, remote_len,
@@ -196,7 +198,17 @@ static void slot_buf_write(nepim_slot_t *slot, char *buf, size_t buf_size, uint8
 
   switch (type) {
   case UDP_TYPE_DATA:
+
+    if (nepim_global.udp_exp_loss > 0)
+      if (!(++slot->exp_loss_sampler % nepim_global.udp_exp_loss))
+	++slot->seq;
+
+    if (nepim_global.udp_exp_dup > 0)
+      if (!(++slot->exp_dup_sampler % nepim_global.udp_exp_dup))
+	--slot->seq;
+
     hdr.seq = slot->seq++;
+
     break;
   case UDP_TYPE_HELLO:
   case UDP_TYPE_KEEPALIVE:
