@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_client.c,v 1.43 2005/09/18 19:37:00 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.45 2005/09/23 12:55:13 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -183,8 +183,9 @@ static void udp_consume(nepim_slot_t *slot, size_t len, uint32_t seq)
 
   nepim_session_read_add(session, len);
 
-  nepim_win_add(&slot->win_recv_seq, seq,
-		&slot->interval_pkt_lost, &slot->interval_pkt_dup);
+  if (nepim_global.udp_exp_stats)
+    nepim_win_add(&slot->win_recv_seq, seq,
+		  &slot->interval_pkt_lost, &slot->interval_pkt_dup);
 }
 
 static void *on_udp_read_segment(oop_source *src, int sd,
@@ -310,6 +311,7 @@ static int slot_greet_write(nepim_slot_t *slot)
   int wr;
   int buf_avail_len;
   int write_len;
+  char *tmp = "";
 
   assert(sizeof(buf) > UDP_HEADER_LEN);
 
@@ -323,6 +325,15 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.udp_keepalive_send    = nepim_global.udp_keepalive_require;
   opt.udp_keepalive_require = nepim_global.udp_keepalive_send;
 
+  if (nepim_global.password) {
+    opt.password_buf        = nepim_global.password;
+    opt.password_buf_size   = strlen(nepim_global.password) + 1;
+  }
+  else {
+    opt.password_buf        = tmp;
+    opt.password_buf_size   = strlen(tmp) + 1;
+  }
+
   buf_avail_len = sizeof(buf) - UDP_HEADER_LEN;
   assert(buf_avail_len > 0);
 
