@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_server.c,v 1.65 2005/09/23 12:55:13 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.67 2005/10/13 19:02:20 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -39,6 +39,7 @@ Boston, MA 02111-1307, USA.
 #include "slot.h"
 #include "usock.h"
 #include "udp_header.h"
+#include "tcpwrap.h"
 
 extern nepim_slot_set_t  slots;   /* from server.c */
 extern nepim_usock_set_t udp_tab; /* from server.c */
@@ -695,6 +696,19 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->write_delay, opt->udp_keepalive_send,
 	  opt->udp_keepalive_require, password_buf);
 
+  if (nepim_global.tcpwrap) {
+    if (!nepim_hosts_ctl(nepim_global.tcpwrap,
+			 nepim_global.prog_name,
+			 peer)) {
+      fprintf(stderr, 
+	      "%d: %d-%d: %s: %s: TCP wrapper denied access from client=[%s] to service=[%s]\n",
+	      sd, local_slot, remote_slot,
+	      __FILE__, __PRETTY_FUNCTION__,
+	      peer, nepim_global.prog_name);
+      return 1;
+    }
+  }
+
   if (nepim_global.password)
     if (strcmp(nepim_global.password, password_buf)) {
       fprintf(stderr, "%d: bad client password=%s\n",
